Crate microsd

Crate microsd 

Light‐weight systemd daemon auxiliars.

This is a set of light‐weight functions to enable socket‐based activation and service manager notification.

Since the environment variables of a process cannot be safely modified in a multi‐threaded setting, the relevant variables passed by the service manager are processed during programme initialisation with the help of the ctor crate.

The primary interface are the listen_fds and notify_socket functions. They are thread‐safe and can each be called only once, consuming any data passed by the service manager.

Re-exports

pub use nix::Error;
pub use nix::sys::socket::AddressFamily;
pub use nix::sys::socket::SockProtocol;
pub use nix::sys::socket::SockType;

Modules

compiocompio
Convenience wrappers for compio types.
std
Convenience wrappers for std types.

Structs

Fd
Generic file descriptor wrapper with file type information.
ListenFdNames
Listen file descriptor names.
ListenFds
Listen file descriptor iterator for undifferentiated Fd.

Functions

listen_fd_names
Retrieve listen file descriptor names.
listen_fds
Retrieve listen file descriptors.
notify_socket
Retrieve notification socket address.