Fd

Struct Fd 

pub struct Fd(/* private fields */);
Generic file descriptor wrapper with file type information.

Implementations

Source

impl Fd

pub fn socket_domain(&self) -> Result<AddressFamily, Error>

Determine socket communication domain.

pub fn socket_type(&self) -> Result<SockType, Error>

Determine socket type.

pub fn socket_protocol(&self) -> Result<Option<SockProtocol>, Error>

Determine socket protocol.

pub fn is_listening(&self) -> Result<bool, Error>

Returns true if the socket is accepting connections.

pub fn is_writeable(&self) -> Result<bool, Error>

Returns true if the file is writeable.

pub unsafe fn try_from(raw: impl IntoRawFd) -> Result<Self, Error>

Construct an Fd from a raw file descriptor.

The file will have its close‐on‐exec flag set.

Safety

The file descriptor must be either unowned or exclusively owned.

pub fn into<T: FromRawFd>(self) -> T

Convert an Fd via raw file descriptor.

While safe, care should be taken to ensure that the semantics of the conversion target fit the type of file represented by the descriptor.